class fake_cache(dict):
	def __init__(self, initial):
		super().__init__()
		self['next'] = initial

	def __enter__(self):
		return self
		
	def __exit__(self, exc_type, exc_val, exc_tb):
		self.write()
		
		if exc_type:
			raise exc_type(exc_val)

	def write(self):
		pass


import argparse

from .batch import batch
from .fake_cache import fake_cache

parser = argparse.ArgumentParser()
parser.add_argument("initial", type=int)
args = parser.parse_args()

class fake_cache_wrapped(fake_cache):
	def __init__(self):
		super().__init__(args.initial)

batch(fake_cache_wrapped)


from infinite_request import infinite_request

def test(n):
	url = "https://ak.hypergryph.com/penguinlogistics/tracking/track?seriesNumber=" + str(n) # 1314752
	txtres = infinite_request(url)
	
	if txtres != '{"success":false,"data":""}':
		return txtres


from concurrent.futures import ThreadPoolExecutor

from ..core import test

class parallel(ThreadPoolExecutor):
	def __init__(self):
		ThreadPoolExecutor.__init__(self, max_workers=100)

	def run(self, queue):
		return self.map(test, queue)


import itertools
from tqdm import tqdm
from ..parallel import parallel

class batch_class:
	def __init__(self, cache):
		self.cache = cache
		self.pool = parallel()

	def batch_work(self):
		queue = self.queue
		
		for n, txtres in zip(queue, self.pool.run(queue)):
			if txtres:
				print(str(n) + '> ' + txtres)
				self.cache[str(n)] = txtres

	def run_naked(self):
		self.queue = []
		initial = self.cache['next']
		
		for i in tqdm(itertools.count(initial), initial=initial):
			if len(self.queue) < 200:
				self.queue.append(i)
			else:
				self.batch_work()
				self.cache['next'] = i+1
				self.cache.write()
				self.queue = []
				
	def run(self):
		try:
			self.run_naked()
		except KeyboardInterrupt:
			return
			# 按Ctrl+C键停止
			# 捕获一下，不让系统输出长得要命的异常提示
			
def batch(cache_type):
	with cache_type() as cache:
		instance = batch_class(cache)
		instance.run()